.. include:: ../BADGES.rst

Python API Function Summary
===========================

.. autosummary::
    :toctree: _function_autosummary

    hydrotoolbox.baseflow_sep.boughton
    hydrotoolbox.baseflow_sep.chapman
    hydrotoolbox.baseflow_sep.cm
    hydrotoolbox.baseflow_sep.eckhardt
    hydrotoolbox.baseflow_sep.ewma
    hydrotoolbox.baseflow_sep.five_day
    hydrotoolbox.baseflow_sep.furey
    hydrotoolbox.baseflow_sep.ihacres
    hydrotoolbox.baseflow_sep.lh
    hydrotoolbox.baseflow_sep.strict
    hydrotoolbox.baseflow_sep.ukih
    hydrotoolbox.baseflow_sep.usgs_hysep_fixed
    hydrotoolbox.baseflow_sep.usgs_hysep_local
    hydrotoolbox.baseflow_sep.usgs_hysep_slide
    hydrotoolbox.baseflow_sep.willems
    hydrotoolbox.exceedance_time
    hydrotoolbox.flow_duration
    hydrotoolbox.indices
    hydrotoolbox.recession
    hydrotoolbox.storm_events
